@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Interface to the Prover9 Theorem Prover
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #         Ewan Klein <ewan@inf.ed.ac.uk>
 #
@@ -9,15 +9,22 @@
 """
 A theorem prover that makes use of the external 'Prover9' package.
 """
-from __future__ import print_function
 
 import os
 import subprocess
 
 import nltk
-from nltk.sem.logic import Expression, ExistsExpression, AllExpression, \
-    NegatedExpression, AndExpression, IffExpression, OrExpression, \
-    EqualityExpression, ImpExpression
+from nltk.sem.logic import (
+    Expression,
+    ExistsExpression,
+    AllExpression,
+    NegatedExpression,
+    AndExpression,
+    IffExpression,
+    OrExpression,
+    EqualityExpression,
+    ImpExpression,
+)
 from nltk.inference.api import BaseProverCommand, Prover
 
 #
@@ -25,16 +32,16 @@ from nltk.inference.api import BaseProverCommand, Prover
 #
 p9_return_codes = {
     0: True,
-    1:  "(FATAL)",      #A fatal error occurred (user's syntax error).
-    2: False,           # (SOS_EMPTY) Prover9 ran out of things to do
-                        #   (sos list exhausted).
-    3: "(MAX_MEGS)",    # The max_megs (memory limit) parameter was exceeded.
-    4: "(MAX_SECONDS)", # The max_seconds parameter was exceeded.
-    5: "(MAX_GIVEN)",   # The max_given parameter was exceeded.
-    6: "(MAX_KEPT)",    # The max_kept parameter was exceeded.
-    7: "(ACTION)",      # A Prover9 action terminated the search.
-    101: "(SIGSEGV)",   # Prover9 crashed, most probably due to a bug.
- }
+    1: "(FATAL)",  # A fatal error occurred (user's syntax error).
+    2: False,  # (SOS_EMPTY) Prover9 ran out of things to do
+    #   (sos list exhausted).
+    3: "(MAX_MEGS)",  # The max_megs (memory limit) parameter was exceeded.
+    4: "(MAX_SECONDS)",  # The max_seconds parameter was exceeded.
+    5: "(MAX_GIVEN)",  # The max_given parameter was exceeded.
+    6: "(MAX_KEPT)",  # The max_kept parameter was exceeded.
+    7: "(ACTION)",  # A Prover9 action terminated the search.
+    101: "(SIGSEGV)",  # Prover9 crashed, most probably due to a bug.
+}
 
 
 class Prover9CommandParent(object):
@@ -43,19 +50,22 @@ class Prover9CommandParent(object):
     which is responsible for maintaining a goal and a set of assumptions,
     and generating prover9-style input files from them.
     """
-    def print_assumptions(self, output_format='nltk'):
+
+    def print_assumptions(self, output_format="nltk"):
         """
         Print the list of the current assumptions.
         """
-        if output_format.lower() == 'nltk':
+        if output_format.lower() == "nltk":
             for a in self.assumptions():
                 print(a)
-        elif output_format.lower() == 'prover9':
+        elif output_format.lower() == "prover9":
             for a in convert_to_prover9(self.assumptions()):
                 print(a)
         else:
-            raise NameError("Unrecognized value for 'output_format': %s" %
-                            output_format)
+            raise NameError(
+                "Unrecognized value for 'output_format': %s" % output_format
+            )
+
 
 class Prover9Command(Prover9CommandParent, BaseProverCommand):
     """
@@ -63,6 +73,7 @@ class Prover9Command(Prover9CommandParent, BaseProverCommand):
     the a print_assumptions() method that is used to print the list
     of assumptions in multiple formats.
     """
+
     def __init__(self, goal=None, assumptions=None, timeout=60, prover=None):
         """
         :param goal: Input expression to prove
@@ -91,7 +102,9 @@ class Prover9Command(Prover9CommandParent, BaseProverCommand):
         :see BaseProverCommand.decorate_proof()
         """
         if simplify:
-            return self._prover._call_prooftrans(proof_string, ['striplabels'])[0].rstrip()
+            return self._prover._call_prooftrans(proof_string, ["striplabels"])[
+                0
+            ].rstrip()
         else:
             return proof_string.rstrip()
 
@@ -110,14 +123,15 @@ class Prover9Parent(object):
             self._binary_location = None
             self._prover9_bin = None
         else:
-            name = 'prover9'
+            name = "prover9"
             self._prover9_bin = nltk.internals.find_binary(
-                                  name,
-                                  path_to_bin=binary_location,
-                                  env_vars=['PROVER9'],
-                                  url='http://www.cs.unm.edu/~mccune/prover9/',
-                                  binary_names=[name, name + '.exe'],
-                                  verbose=verbose)
+                name,
+                path_to_bin=binary_location,
+                env_vars=["PROVER9"],
+                url="http://www.cs.unm.edu/~mccune/prover9/",
+                binary_names=[name, name + ".exe"],
+                verbose=verbose,
+            )
             self._binary_location = self._prover9_bin.rsplit(os.path.sep, 1)
 
     def prover9_input(self, goal, assumptions):
@@ -126,18 +140,18 @@ class Prover9Parent(object):
         prover9 binary.  This string is formed based on the goal,
         assumptions, and timeout value of this object.
         """
-        s = ''
+        s = ""
 
         if assumptions:
-            s += 'formulas(assumptions).\n'
+            s += "formulas(assumptions).\n"
             for p9_assumption in convert_to_prover9(assumptions):
-                s += '    %s.\n' % p9_assumption
-            s += 'end_of_list.\n\n'
+                s += "    %s.\n" % p9_assumption
+            s += "end_of_list.\n\n"
 
         if goal:
-            s += 'formulas(goals).\n'
-            s += '    %s.\n' % convert_to_prover9(goal)
-            s += 'end_of_list.\n\n'
+            s += "formulas(goals).\n"
+            s += "    %s.\n" % convert_to_prover9(goal)
+            s += "end_of_list.\n\n"
 
         return s
 
@@ -147,23 +161,27 @@ class Prover9Parent(object):
         executables.  This list is used by ``config_prover9`` when searching
         for the prover9 executables.
         """
-        return ['/usr/local/bin/prover9',
-                '/usr/local/bin/prover9/bin',
-                '/usr/local/bin',
-                '/usr/bin',
-                '/usr/local/prover9',
-                '/usr/local/share/prover9']
+        return [
+            "/usr/local/bin/prover9",
+            "/usr/local/bin/prover9/bin",
+            "/usr/local/bin",
+            "/usr/bin",
+            "/usr/local/prover9",
+            "/usr/local/share/prover9",
+        ]
 
     def _find_binary(self, name, verbose=False):
         binary_locations = self.binary_locations()
         if self._binary_location is not None:
             binary_locations += [self._binary_location]
-        return nltk.internals.find_binary(name,
+        return nltk.internals.find_binary(
+            name,
             searchpath=binary_locations,
-            env_vars=['PROVER9'],
-            url='http://www.cs.unm.edu/~mccune/prover9/',
-            binary_names=[name, name + '.exe'],
-            verbose=verbose)
+            env_vars=["PROVER9"],
+            url="http://www.cs.unm.edu/~mccune/prover9/",
+            binary_names=[name, name + ".exe"],
+            verbose=verbose,
+        )
 
     def _call(self, input_str, binary, args=[], verbose=False):
         """
@@ -176,9 +194,9 @@ class Prover9Parent(object):
         :see: ``config_prover9``
         """
         if verbose:
-            print('Calling:', binary)
-            print('Args:', args)
-            print('Input:\n', input_str, '\n')
+            print("Calling:", binary)
+            print("Args:", args)
+            print("Input:\n", input_str, "\n")
 
         # Call prover9 via a subprocess
         cmd = [binary] + args
@@ -186,15 +204,17 @@ class Prover9Parent(object):
             input_str = input_str.encode("utf8")
         except AttributeError:
             pass
-        p = subprocess.Popen(cmd, stdout=subprocess.PIPE,
-                             stderr=subprocess.STDOUT,
-                             stdin=subprocess.PIPE)
+        p = subprocess.Popen(
+            cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE
+        )
         (stdout, stderr) = p.communicate(input=input_str)
 
         if verbose:
-            print('Return code:', p.returncode)
-            if stdout: print('stdout:\n', stdout, '\n')
-            if stderr: print('stderr:\n', stderr, '\n')
+            print("Return code:", p.returncode)
+            if stdout:
+                print("stdout:\n", stdout, "\n")
+            if stderr:
+                print("stderr:\n", stderr, "\n")
 
         return (stdout.decode("utf-8"), p.returncode)
 
@@ -209,41 +229,77 @@ def convert_to_prover9(input):
             try:
                 result.append(_convert_to_prover9(s.simplify()))
             except:
-                print('input %s cannot be converted to Prover9 input syntax' % input)
+                print("input %s cannot be converted to Prover9 input syntax" % input)
                 raise
         return result
     else:
         try:
             return _convert_to_prover9(input.simplify())
         except:
-            print('input %s cannot be converted to Prover9 input syntax' % input)
+            print("input %s cannot be converted to Prover9 input syntax" % input)
             raise
 
+
 def _convert_to_prover9(expression):
     """
     Convert ``logic.Expression`` to Prover9 formatted string.
     """
     if isinstance(expression, ExistsExpression):
-        return 'exists ' + str(expression.variable) + ' ' + _convert_to_prover9(expression.term)
+        return (
+            "exists "
+            + str(expression.variable)
+            + " "
+            + _convert_to_prover9(expression.term)
+        )
     elif isinstance(expression, AllExpression):
-        return 'all ' + str(expression.variable) + ' ' + _convert_to_prover9(expression.term)
+        return (
+            "all "
+            + str(expression.variable)
+            + " "
+            + _convert_to_prover9(expression.term)
+        )
     elif isinstance(expression, NegatedExpression):
-        return '-(' + _convert_to_prover9(expression.term) + ')'
+        return "-(" + _convert_to_prover9(expression.term) + ")"
     elif isinstance(expression, AndExpression):
-        return '(' + _convert_to_prover9(expression.first) + ' & ' + \
-                     _convert_to_prover9(expression.second) + ')'
+        return (
+            "("
+            + _convert_to_prover9(expression.first)
+            + " & "
+            + _convert_to_prover9(expression.second)
+            + ")"
+        )
     elif isinstance(expression, OrExpression):
-        return '(' + _convert_to_prover9(expression.first) + ' | ' + \
-                     _convert_to_prover9(expression.second) + ')'
+        return (
+            "("
+            + _convert_to_prover9(expression.first)
+            + " | "
+            + _convert_to_prover9(expression.second)
+            + ")"
+        )
     elif isinstance(expression, ImpExpression):
-        return '(' + _convert_to_prover9(expression.first) + ' -> ' + \
-                     _convert_to_prover9(expression.second) + ')'
+        return (
+            "("
+            + _convert_to_prover9(expression.first)
+            + " -> "
+            + _convert_to_prover9(expression.second)
+            + ")"
+        )
     elif isinstance(expression, IffExpression):
-        return '(' + _convert_to_prover9(expression.first) + ' <-> ' + \
-                     _convert_to_prover9(expression.second) + ')'
+        return (
+            "("
+            + _convert_to_prover9(expression.first)
+            + " <-> "
+            + _convert_to_prover9(expression.second)
+            + ")"
+        )
     elif isinstance(expression, EqualityExpression):
-        return '(' + _convert_to_prover9(expression.first) + ' = ' + \
-                     _convert_to_prover9(expression.second) + ')'
+        return (
+            "("
+            + _convert_to_prover9(expression.first)
+            + " = "
+            + _convert_to_prover9(expression.second)
+            + ")"
+        )
     else:
         return str(expression)
 
@@ -268,15 +324,16 @@ class Prover9(Prover9Parent, Prover):
         if not assumptions:
             assumptions = []
 
-        stdout, returncode = self._call_prover9(self.prover9_input(goal, assumptions),
-                                                verbose=verbose)
+        stdout, returncode = self._call_prover9(
+            self.prover9_input(goal, assumptions), verbose=verbose
+        )
         return (returncode == 0, stdout)
 
     def prover9_input(self, goal, assumptions):
         """
         :see: Prover9Parent.prover9_input
         """
-        s = 'clear(auto_denials).\n' #only one proof required
+        s = "clear(auto_denials).\n"  # only one proof required
         return s + Prover9Parent.prover9_input(self, goal, assumptions)
 
     def _call_prover9(self, input_str, args=[], verbose=False):
@@ -289,23 +346,25 @@ class Prover9(Prover9Parent, Prover):
         :see: ``config_prover9``
         """
         if self._prover9_bin is None:
-            self._prover9_bin = self._find_binary('prover9', verbose)
+            self._prover9_bin = self._find_binary("prover9", verbose)
 
-        updated_input_str = ''
+        updated_input_str = ""
         if self._timeout > 0:
-            updated_input_str += 'assign(max_seconds, %d).\n\n' % self._timeout
+            updated_input_str += "assign(max_seconds, %d).\n\n" % self._timeout
         updated_input_str += input_str
 
-        stdout, returncode = self._call(updated_input_str, self._prover9_bin, args, verbose)
+        stdout, returncode = self._call(
+            updated_input_str, self._prover9_bin, args, verbose
+        )
 
-        if returncode not in [0,2]:
-            errormsgprefix = '%%ERROR:'
+        if returncode not in [0, 2]:
+            errormsgprefix = "%%ERROR:"
             if errormsgprefix in stdout:
                 msgstart = stdout.index(errormsgprefix)
                 errormsg = stdout[msgstart:].strip()
             else:
                 errormsg = None
-            if returncode in [3,4,5,6]:
+            if returncode in [3, 4, 5, 6]:
                 raise Prover9LimitExceededException(returncode, errormsg)
             else:
                 raise Prover9FatalException(returncode, errormsg)
@@ -322,7 +381,7 @@ class Prover9(Prover9Parent, Prover):
         :see: ``config_prover9``
         """
         if self._prooftrans_bin is None:
-            self._prooftrans_bin = self._find_binary('prooftrans', verbose)
+            self._prooftrans_bin = self._find_binary("prooftrans", verbose)
 
         return self._call(input_str, self._prooftrans_bin, args, verbose)
 
@@ -331,33 +390,36 @@ class Prover9Exception(Exception):
     def __init__(self, returncode, message):
         msg = p9_return_codes[returncode]
         if message:
-            msg += '\n%s' % message
+            msg += "\n%s" % message
         Exception.__init__(self, msg)
 
+
 class Prover9FatalException(Prover9Exception):
     pass
 
+
 class Prover9LimitExceededException(Prover9Exception):
     pass
 
 
+######################################################################
+# { Tests and Demos
+######################################################################
 
-######################################################################
-#{ Tests and Demos
-######################################################################
 
 def test_config():
 
-    a = Expression.fromstring('(walk(j) & sing(j))')
-    g = Expression.fromstring('walk(j)')
+    a = Expression.fromstring("(walk(j) & sing(j))")
+    g = Expression.fromstring("walk(j)")
     p = Prover9Command(g, assumptions=[a])
     p._executable_path = None
-    p.prover9_search=[]
+    p.prover9_search = []
     p.prove()
-    #config_prover9('/usr/local/bin')
+    # config_prover9('/usr/local/bin')
     print(p.prove())
     print(p.proof())
 
+
 def test_convert_to_prover9(expr):
     """
     Test that parsing works OK.
@@ -366,6 +428,7 @@ def test_convert_to_prover9(expr):
         e = Expression.fromstring(t)
         print(convert_to_prover9(e))
 
+
 def test_prove(arguments):
     """
     Try some proofs and exhibit the results.
@@ -375,44 +438,57 @@ def test_prove(arguments):
         alist = [Expression.fromstring(a) for a in assumptions]
         p = Prover9Command(g, assumptions=alist).prove()
         for a in alist:
-            print('   %s' % a)
-        print('|- %s: %s\n' % (g, p))
+            print("   %s" % a)
+        print("|- %s: %s\n" % (g, p))
+
 
 arguments = [
-    ('(man(x) <-> (not (not man(x))))', []),
-    ('(not (man(x) & (not man(x))))', []),
-    ('(man(x) | (not man(x)))', []),
-    ('(man(x) & (not man(x)))', []),
-    ('(man(x) -> man(x))', []),
-    ('(not (man(x) & (not man(x))))', []),
-    ('(man(x) | (not man(x)))', []),
-    ('(man(x) -> man(x))', []),
-    ('(man(x) <-> man(x))', []),
-    ('(not (man(x) <-> (not man(x))))', []),
-    ('mortal(Socrates)', ['all x.(man(x) -> mortal(x))', 'man(Socrates)']),
-    ('((all x.(man(x) -> walks(x)) & man(Socrates)) -> some y.walks(y))', []),
-    ('(all x.man(x) -> all x.man(x))', []),
-    ('some x.all y.sees(x,y)', []),
-    ('some e3.(walk(e3) & subj(e3, mary))',
-        ['some e1.(see(e1) & subj(e1, john) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))']),
-    ('some x e1.(see(e1) & subj(e1, x) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))',
-       ['some e1.(see(e1) & subj(e1, john) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))'])
+    ("(man(x) <-> (not (not man(x))))", []),
+    ("(not (man(x) & (not man(x))))", []),
+    ("(man(x) | (not man(x)))", []),
+    ("(man(x) & (not man(x)))", []),
+    ("(man(x) -> man(x))", []),
+    ("(not (man(x) & (not man(x))))", []),
+    ("(man(x) | (not man(x)))", []),
+    ("(man(x) -> man(x))", []),
+    ("(man(x) <-> man(x))", []),
+    ("(not (man(x) <-> (not man(x))))", []),
+    ("mortal(Socrates)", ["all x.(man(x) -> mortal(x))", "man(Socrates)"]),
+    ("((all x.(man(x) -> walks(x)) & man(Socrates)) -> some y.walks(y))", []),
+    ("(all x.man(x) -> all x.man(x))", []),
+    ("some x.all y.sees(x,y)", []),
+    (
+        "some e3.(walk(e3) & subj(e3, mary))",
+        [
+            "some e1.(see(e1) & subj(e1, john) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))"
+        ],
+    ),
+    (
+        "some x e1.(see(e1) & subj(e1, x) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))",
+        [
+            "some e1.(see(e1) & subj(e1, john) & some e2.(pred(e1, e2) & walk(e2) & subj(e2, mary)))"
+        ],
+    ),
+]
+
+expressions = [
+    r"some x y.sees(x,y)",
+    r"some x.(man(x) & walks(x))",
+    r"\x.(man(x) & walks(x))",
+    r"\x y.sees(x,y)",
+    r"walks(john)",
+    r"\x.big(x, \y.mouse(y))",
+    r"(walks(x) & (runs(x) & (threes(x) & fours(x))))",
+    r"(walks(x) -> runs(x))",
+    r"some x.(PRO(x) & sees(John, x))",
+    r"some x.(man(x) & (not walks(x)))",
+    r"all x.(man(x) -> walks(x))",
 ]
 
-expressions = [r'some x y.sees(x,y)',
-               r'some x.(man(x) & walks(x))',
-               r'\x.(man(x) & walks(x))',
-               r'\x y.sees(x,y)',
-               r'walks(john)',
-               r'\x.big(x, \y.mouse(y))',
-               r'(walks(x) & (runs(x) & (threes(x) & fours(x))))',
-               r'(walks(x) -> runs(x))',
-               r'some x.(PRO(x) & sees(John, x))',
-               r'some x.(man(x) & (not walks(x)))',
-               r'all x.(man(x) -> walks(x))']
 
 def spacer(num=45):
-    print('-' * num)
+    print("-" * num)
+
 
 def demo():
     print("Testing configuration")
@@ -427,5 +503,6 @@ def demo():
     spacer()
     test_prove(arguments)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     demo()
