@@ -1,15 +1,13 @@
 # -*- coding: utf-8 -*-
 
-
-def setup_module(module):
-    from nose import SkipTest
+def setup_module():
+    import pytest
     import nltk.data
 
     try:
         nltk.data.find("corpora/childes/data-xml/Eng-USA-MOR/")
     except LookupError as e:
-        print(e)
-        raise SkipTest(
+        pytest.skip(
             "The CHILDES corpus is not found. "
             "It should be manually downloaded and saved/unpacked "
             "to [NLTK_Data_Dir]/corpora/childes/"
